using System;
using RJH.CommandLineHelper;

//
// DtsToSsisPrepare
// written by Marco Russo (marco.russo@sqlbi.eu)
// Download latest version from www.sqlbi.eu
//
// This tool convert a DTS file into another DTS file that can be better migrated to SSIS using standard wizard
// Read details in upcoming article on www.sqlbi.eu
//
// Please note we are using code from Automatic Command Line Parsing in C# by Ray Hayes
// Read article and download original code from: http://www.codeproject.com/csharp/commandlineparser.asp?df=100
//

namespace SqlBi.DtsToSsisPrepare {
    class Program {

        Parser parser;
        PackageMigration migration;
        
        public Program() {
            migration = new PackageMigration();
        }
        
        protected void ShowHelp() {
            Console.WriteLine( "Syntax: DtsToSsisPrepare.exe [switch:value]" );
            // Walk through all of the registered switches getting the available
            // information back out.
            Parser.SwitchInfo[] si = parser.Switches;
            if (si != null) {
                foreach (Parser.SwitchInfo s in si) {
                    Console.WriteLine( "  /{0}\r\n     {1}", s.Name, s.Description );
                }
            }
        }
        protected void Run( string[] args ) {
            // Initialise the command line parser, passing in a reference to this
            // class so that we can look for any attributes that implement
            // command line switches.
            parser = new Parser( Environment.CommandLine, migration.Parameters );

            // Add a switches with lots of aliases for the first name, "help" and "a".
            parser.AddSwitch( new string[] { "help", @"\?" }, "show help" );
            parser.AddSwitch( new string[] { "all", @"\?" }, "Activate all conversion features" );
            parser.Parse();

            Console.WriteLine( "Dts to SSIS Prepare {0}",
                               System.Reflection.Assembly.GetExecutingAssembly().GetName().Version.ToString() );
           
            if (parser["help"] != null) {
                ShowHelp();
                return;
            }
            if (parser["all"] != null) {
                migration.Parameters.SetAll();
            }
            
            // Argument output
            Console.WriteLine( "Arguments:");
            Parser.SwitchInfo[] si = parser.Switches;
            if (si != null) {
                foreach (Parser.SwitchInfo s in si) {
                    if (s.Value != null) {
                        Console.WriteLine( "  {0} : {1}", s.Name.PadRight( 30 ), s.Value != null ? s.Value : "(Unknown)" );
                    }
                }
            }

            migration.Migrate();
        }
        
        static void Main( string[] args ) {
            Program program = new Program();
            program.Run( args );
        }
    }
}
